/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FLANGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FLANGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FLANGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FLANGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FLANGR::Heavy_WSTD_FLANGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_v95Gy9DU);
  numBytes += sPhasor_k_init(&sPhasor_Ls2aYHQK, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_RsR9btNi);
  numBytes += sRPole_init(&sRPole_WvLNFL99);
  numBytes += sRPole_init(&sRPole_lLgFnuVU);
  numBytes += sTabhead_init(&sTabhead_6xCczABB, &hTable_dh73MCvo);
  numBytes += sTabread_init(&sTabread_Wl1SMhCh, &hTable_dh73MCvo, false);
  numBytes += sTabread_init(&sTabread_ABuRdw3C, &hTable_dh73MCvo, false);
  numBytes += sLine_init(&sLine_mCikxCKZ);
  numBytes += sTabhead_init(&sTabhead_5kidU1NS, &hTable_XuXSLJKI);
  numBytes += sTabread_init(&sTabread_Aph5mmhV, &hTable_XuXSLJKI, false);
  numBytes += sTabread_init(&sTabread_kpMe1xQ4, &hTable_XuXSLJKI, false);
  numBytes += sLine_init(&sLine_AcjqgN0E);
  numBytes += sTabwrite_init(&sTabwrite_oOkSPzYC, &hTable_XuXSLJKI);
  numBytes += sTabwrite_init(&sTabwrite_cmQQ1WiW, &hTable_dh73MCvo);
  numBytes += cVar_init_f(&cVar_bmh3msR8, 0.0f);
  numBytes += cVar_init_f(&cVar_6ScDnEN2, 0.0f);
  numBytes += cVar_init_f(&cVar_iU2sp8qX, 0.0f);
  numBytes += cVar_init_f(&cVar_KkdYGMiT, 0.0f);
  numBytes += cVar_init_s(&cVar_UmUSyyQ1, "del-1010-flanger-l");
  numBytes += sVarf_init(&sVarf_sPCLE0Ew, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_d9K8x5EM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GATTzl0e, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_OB6vEMbV, "del-1010-flanger-r");
  numBytes += sVarf_init(&sVarf_BpcX2vdC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KkeUbrj2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6WlGvP95, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_dQmWTum8, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Pg5eDwCG, 0.0f);
  numBytes += hTable_init(&hTable_XuXSLJKI, 256);
  numBytes += cDelay_init(this, &cDelay_JQj6kaOt, 0.0f);
  numBytes += cDelay_init(this, &cDelay_hdGzO2kT, 0.0f);
  numBytes += hTable_init(&hTable_dh73MCvo, 256);
  numBytes += cVar_init_f(&cVar_9PnoCOyu, 14.0f);
  numBytes += cBinop_init(&cBinop_nymZzzbD, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_RD5legC0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3Nxvy3I8, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_H9f5b0kF, 14.0f);
  numBytes += cBinop_init(&cBinop_DFfC0Xla, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_qQEsPzzO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HG38Sw2Q, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_YPi80CDP, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_MrOPaoeR, 1, -1);
  numBytes += cVar_init_f(&cVar_qXnHcB16, 0.2f);
  numBytes += cSlice_init(&cSlice_cx1ii3Os, 1, -1);
  numBytes += cVar_init_f(&cVar_3803VhGc, 0.0f);
  numBytes += cSlice_init(&cSlice_2iFjGfeb, 1, -1);
  numBytes += cVar_init_f(&cVar_6LWwCAR3, 2.0f);
  numBytes += cSlice_init(&cSlice_ENgNmkxM, 1, -1);
  numBytes += cVar_init_f(&cVar_yrzQLza0, 0.5f);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FLANGR::~Heavy_WSTD_FLANGR() {
  hTable_free(&hTable_XuXSLJKI);
  hTable_free(&hTable_dh73MCvo);
}

HvTable *Heavy_WSTD_FLANGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x297C7484: return &hTable_XuXSLJKI; // del-1010-flanger-r
    case 0x7DBB345F: return &hTable_dh73MCvo; // del-1010-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FLANGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wPNZJxxw_sendMessage);
      break;
    }
    case 0x20BB009B: { // Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_olrsBJ8C_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HqEXF0l9_sendMessage);
      break;
    }
    case 0x9A248230: { // Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_z9I6b4PB_sendMessage);
      break;
    }
    case 0xD6AF3228: { // 1010-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qSMX4BmN_sendMessage);
      break;
    }
    case 0x68077D82: { // 1010-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_x7ZtoMpl_sendMessage);
      break;
    }
    case 0x36F9AB4: { // 1010-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IdVf8Hr7_sendMessage);
      break;
    }
    case 0xF709FF0E: { // 1010-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Rw4qb8m2_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_owaOUGzL_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FLANGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Intensity";
        info->hash = 0x20BB009B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Speed";
        info->hash = 0x9A248230;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FLANGR::cVar_bmh3msR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bX94ZgIX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_6ScDnEN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ODhUBgRb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_iU2sp8qX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nnNwWt0i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_KkdYGMiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2LQReQVT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_dU4s51nF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_3taU04Is_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_3taU04Is_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_Ls2aYHQK, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_rFNGYnsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8iKLYl7B_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_8iKLYl7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yRsAwExd_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_UmUSyyQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ASlc9GRf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_Sdy0y24w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_7CG3hPQm_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_sPCLE0Ew, m);
}

void Heavy_WSTD_FLANGR::cBinop_yRsAwExd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_d9K8x5EM, m);
}

void Heavy_WSTD_FLANGR::cMsg_ASlc9GRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Sdy0y24w_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_7CG3hPQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GATTzl0e, m);
}

void Heavy_WSTD_FLANGR::cMsg_8Qx3uXiW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wgsLuAb0_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_wgsLuAb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_NuwUz9y3_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_OB6vEMbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2QPaZpPk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_dny4Hqbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_i8eGDwm8_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BpcX2vdC, m);
}

void Heavy_WSTD_FLANGR::cBinop_NuwUz9y3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_KkeUbrj2, m);
}

void Heavy_WSTD_FLANGR::cMsg_2QPaZpPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dny4Hqbl_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_i8eGDwm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6WlGvP95, m);
}

void Heavy_WSTD_FLANGR::cBinop_Kuf33ZKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_jHFMHdIh_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_jHFMHdIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_yGlZLUwT_sendMessage);
}

void Heavy_WSTD_FLANGR::cUnop_RlQvET0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DYNoz3ht_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cUnop_oEEWcY7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mFeajoOU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_yGlZLUwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_8wAhAN2V_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_8wAhAN2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NvI9nAqa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P2wMnJ9v_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_P2wMnJ9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w67u24aU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cCast_NvI9nAqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_CUzfUuSE_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_CUzfUuSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0azvQ0Sp_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_w67u24aU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_J3IPFYZZ_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_J3IPFYZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uSy1dwkt_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_0azvQ0Sp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_RlQvET0K_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_uSy1dwkt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_oEEWcY7L_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_sTAF5m5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_QblfbsDk_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_QblfbsDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HDquHnBU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_gm69b8wr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZOiFh60F_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_ZOiFh60F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_5VeDqcp1_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_dQmWTum8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dQmWTum8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Pg5eDwCG, 0, m, &cDelay_Pg5eDwCG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dQmWTum8, 0, m, &cDelay_dQmWTum8_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_oOkSPzYC, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_Pg5eDwCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Pg5eDwCG, m);
  cMsg_IKZVYy1C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_q03QOMBv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_cu7K1RuY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_T4bDQoQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6sAbQxFN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_XuXSLJKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9S0OIqi9_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dQmWTum8, 2, m, &cDelay_dQmWTum8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t55f0ITr_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_6sAbQxFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_XuXSLJKI, 0, m, &hTable_XuXSLJKI_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_5VeDqcp1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_T4bDQoQp_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_IKZVYy1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_XuXSLJKI, 0, m, &hTable_XuXSLJKI_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_t55f0ITr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dQmWTum8, 0, m, &cDelay_dQmWTum8_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_9S0OIqi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Pg5eDwCG, 2, m, &cDelay_Pg5eDwCG_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_cu7K1RuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_oOkSPzYC, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_iQAPdj3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_79EBtvYd_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_79EBtvYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cbmwTqdB_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_JQj6kaOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JQj6kaOt, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hdGzO2kT, 0, m, &cDelay_hdGzO2kT_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JQj6kaOt, 0, m, &cDelay_JQj6kaOt_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_cmQQ1WiW, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_hdGzO2kT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hdGzO2kT, m);
  cMsg_zy412zK9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_PwI2pR3g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_0vgMFAd8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_an7I2YlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jqmvJ1BT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_dh73MCvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zYrsD4jo_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JQj6kaOt, 2, m, &cDelay_JQj6kaOt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7Tr7MAYM_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_jqmvJ1BT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_dh73MCvo, 0, m, &hTable_dh73MCvo_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_cbmwTqdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_an7I2YlE_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_zy412zK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_dh73MCvo, 0, m, &hTable_dh73MCvo_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_7Tr7MAYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JQj6kaOt, 0, m, &cDelay_JQj6kaOt_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_zYrsD4jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_hdGzO2kT, 2, m, &cDelay_hdGzO2kT_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_0vgMFAd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_cmQQ1WiW, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cVar_9PnoCOyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nymZzzbD, HV_BINOP_MULTIPLY, 0, m, &cBinop_nymZzzbD_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_DNwd9br0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uGJkGStC_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_uGJkGStC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3OOcMCoY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_nymZzzbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_7F5KOczm_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_rEASrGWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nymZzzbD, HV_BINOP_MULTIPLY, 1, m, &cBinop_nymZzzbD_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_3OOcMCoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_rEASrGWd_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_7F5KOczm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_xxgHGyrz_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_xxgHGyrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_WYjfM40z_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_3Nxvy3I8, m);
}

void Heavy_WSTD_FLANGR::cBinop_WYjfM40z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_RD5legC0, m);
}

void Heavy_WSTD_FLANGR::cVar_H9f5b0kF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DFfC0Xla, HV_BINOP_MULTIPLY, 0, m, &cBinop_DFfC0Xla_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_Hvuzng6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eykct4na_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_eykct4na_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NNxp8IMW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_DFfC0Xla_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_uIWBCiAh_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_Y6SvP16p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DFfC0Xla, HV_BINOP_MULTIPLY, 1, m, &cBinop_DFfC0Xla_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_NNxp8IMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Y6SvP16p_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_uIWBCiAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_04PE3qBO_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_04PE3qBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_4uO9w57y_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_HG38Sw2Q, m);
}

void Heavy_WSTD_FLANGR::cBinop_4uO9w57y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qQEsPzzO, m);
}

void Heavy_WSTD_FLANGR::cMsg_HDquHnBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RsR9btNi, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cUnop_jaZ8z8hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_naWFw9J8_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_Kh51jM15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_jaZ8z8hb_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_QA4NjYk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_SueNE6xJ_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_jZxprkHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_SNCqhAuZ_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_SNCqhAuZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YPi80CDP, HV_BINOP_MULTIPLY, 1, m, &cBinop_YPi80CDP_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_SueNE6xJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_jZxprkHg_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_YPi80CDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oGWxHFKN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_naWFw9J8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YPi80CDP, HV_BINOP_MULTIPLY, 0, m, &cBinop_YPi80CDP_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_oGWxHFKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AcjqgN0E, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_hxSqN5eQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_swIOgw3c_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_swIOgw3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QA4NjYk6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Kh51jM15_sendMessage);
}

void Heavy_WSTD_FLANGR::cSwitchcase_oQqjXCyX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MrOPaoeR, 0, m, &cSlice_MrOPaoeR_sendMessage);
      break;
    }
    default: {
      cSwitchcase_eclcKDUB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_MrOPaoeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2WOEKO4z_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2WOEKO4z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_qXnHcB16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2WOEKO4z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_2WOEKO4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_x7ZtoMpl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_eclcKDUB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cx1ii3Os, 0, m, &cSlice_cx1ii3Os_sendMessage);
      break;
    }
    default: {
      cSwitchcase_z4QeGLbv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_cx1ii3Os_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CSYkGpFk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CSYkGpFk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_3803VhGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CSYkGpFk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_CSYkGpFk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qSMX4BmN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_z4QeGLbv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2iFjGfeb, 0, m, &cSlice_2iFjGfeb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JuKlUzv7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_2iFjGfeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_53QfbnhP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_53QfbnhP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_6LWwCAR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_53QfbnhP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_53QfbnhP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Rw4qb8m2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_JuKlUzv7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ENgNmkxM, 0, m, &cSlice_ENgNmkxM_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_ENgNmkxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ITKC8MRO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ITKC8MRO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_yrzQLza0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ITKC8MRO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_ITKC8MRO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IdVf8Hr7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_DYNoz3ht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mCikxCKZ, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_mFeajoOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v95Gy9DU, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_2LQReQVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_oQqjXCyX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_bX94ZgIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_oQqjXCyX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_ODhUBgRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_oQqjXCyX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_nnNwWt0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_oQqjXCyX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_eHOErdVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KkdYGMiT, 0, m, &cVar_KkdYGMiT_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_V0pjFmHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bmh3msR8, 0, m, &cVar_bmh3msR8_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_7nmOYnnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iU2sp8qX, 0, m, &cVar_iU2sp8qX_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_Rw4qb8m2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_dU4s51nF_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_qSMX4BmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hxSqN5eQ_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_owaOUGzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DNwd9br0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_9PnoCOyu, 0, m, &cVar_9PnoCOyu_sendMessage);
  cMsg_Hvuzng6d_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_H9f5b0kF, 0, m, &cVar_H9f5b0kF_sendMessage);
  cMsg_gm69b8wr_sendMessage(_c, 0, m);
  cMsg_iQAPdj3L_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_qXnHcB16, 0, m, &cVar_qXnHcB16_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3803VhGc, 0, m, &cVar_3803VhGc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6LWwCAR3, 0, m, &cVar_6LWwCAR3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yrzQLza0, 0, m, &cVar_yrzQLza0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UmUSyyQ1, 0, m, &cVar_UmUSyyQ1_sendMessage);
  cMsg_rFNGYnsh_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_OB6vEMbV, 0, m, &cVar_OB6vEMbV_sendMessage);
  cMsg_8Qx3uXiW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cReceive_IdVf8Hr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Kuf33ZKD_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_x7ZtoMpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_sTAF5m5z_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_z9I6b4PB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6ScDnEN2, 0, m, &cVar_6ScDnEN2_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_HqEXF0l9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_eHOErdVV_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_olrsBJ8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_7nmOYnnK_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_wPNZJxxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_V0pjFmHY_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FLANGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_v95Gy9DU, VOf(Bf0));
    __hv_phasor_k_f(&sPhasor_Ls2aYHQK, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_RsR9btNi, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf3));
    __hv_varread_f(&sVarf_3Nxvy3I8, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_RD5legC0, VOf(Bf3));
    __hv_rpole_f(&sRPole_WvLNFL99, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_HG38Sw2Q, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_qQEsPzzO, VOf(Bf4));
    __hv_rpole_f(&sRPole_lLgFnuVU, VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_tabhead_f(&sTabhead_6xCczABB, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_d9K8x5EM, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_GATTzl0e, VOf(Bf4));
    __hv_min_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_sPCLE0Ew, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_lt_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_and_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_cast_fi(VIf(Bf5), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_Wl1SMhCh, VIi(Bi1), VOf(Bf5));
    __hv_tabread_if(&sTabread_ABuRdw3C, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf5), VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_mCikxCKZ, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf5));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_5kidU1NS, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_KkeUbrj2, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_6WlGvP95, VOf(Bf3));
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_varread_f(&sVarf_BpcX2vdC, VOf(Bf3));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf3), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_Aph5mmhV, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_kpMe1xQ4, VIi(Bi0), VOf(Bf3));
    __hv_sub_f(VIf(Bf7), VIf(Bf3), VOf(Bf7));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(I1), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_AcjqgN0E, VOf(Bf0));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(I1), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_oOkSPzYC, VIf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf0), VIf(I0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_cmQQ1WiW, VIf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FLANGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FLANGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
