/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
#define _HEAVY_CONTEXT_WSTD_FLANGR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlCast.h"
#include "HvSignalPhasor.h"
#include "HvSignalTabread.h"
#include "HvSignalTabwrite.h"
#include "HvControlDelay.h"
#include "HvMath.h"
#include "HvControlSlice.h"
#include "HvSignalDel1.h"
#include "HvSignalRPole.h"
#include "HvControlVar.h"
#include "HvControlSystem.h"
#include "HvSignalLine.h"
#include "HvTable.h"
#include "HvSignalVar.h"
#include "HvControlBinop.h"
#include "HvControlUnop.h"

class Heavy_WSTD_FLANGR : public HeavyContext {

 public:
  Heavy_WSTD_FLANGR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_FLANGR();

  const char *getName() override { return "WSTD_FLANGR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        FEEDBACK = 0x57157946, // Feedback
        INTENSITY = 0x20BB009B, // Intensity
        MIX = 0x97D46AC6, // Mix
        SPEED = 0x9A248230, // Speed
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_bmh3msR8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6ScDnEN2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iU2sp8qX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KkdYGMiT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dU4s51nF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3taU04Is_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rFNGYnsh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8iKLYl7B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UmUSyyQ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Sdy0y24w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yRsAwExd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ASlc9GRf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7CG3hPQm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8Qx3uXiW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wgsLuAb0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OB6vEMbV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dny4Hqbl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NuwUz9y3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2QPaZpPk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i8eGDwm8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kuf33ZKD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jHFMHdIh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_RlQvET0K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_oEEWcY7L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yGlZLUwT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8wAhAN2V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P2wMnJ9v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NvI9nAqa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CUzfUuSE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w67u24aU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J3IPFYZZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0azvQ0Sp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uSy1dwkt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sTAF5m5z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QblfbsDk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gm69b8wr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ZOiFh60F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_dQmWTum8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Pg5eDwCG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_q03QOMBv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_T4bDQoQp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_XuXSLJKI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6sAbQxFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5VeDqcp1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IKZVYy1C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t55f0ITr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9S0OIqi9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cu7K1RuY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iQAPdj3L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_79EBtvYd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_JQj6kaOt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hdGzO2kT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PwI2pR3g_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_an7I2YlE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_dh73MCvo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jqmvJ1BT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cbmwTqdB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zy412zK9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7Tr7MAYM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zYrsD4jo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0vgMFAd8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9PnoCOyu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DNwd9br0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_uGJkGStC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nymZzzbD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rEASrGWd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3OOcMCoY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7F5KOczm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xxgHGyrz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WYjfM40z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_H9f5b0kF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Hvuzng6d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_eykct4na_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DFfC0Xla_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y6SvP16p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NNxp8IMW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uIWBCiAh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_04PE3qBO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4uO9w57y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HDquHnBU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jaZ8z8hb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Kh51jM15_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QA4NjYk6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jZxprkHg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SNCqhAuZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SueNE6xJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YPi80CDP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_naWFw9J8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oGWxHFKN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hxSqN5eQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_swIOgw3c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oQqjXCyX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_MrOPaoeR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qXnHcB16_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_2WOEKO4z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_eclcKDUB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_cx1ii3Os_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3803VhGc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CSYkGpFk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_z4QeGLbv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_2iFjGfeb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6LWwCAR3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_53QfbnhP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JuKlUzv7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ENgNmkxM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yrzQLza0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ITKC8MRO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DYNoz3ht_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mFeajoOU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2LQReQVT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bX94ZgIX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ODhUBgRb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nnNwWt0i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eHOErdVV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V0pjFmHY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7nmOYnnK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Rw4qb8m2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qSMX4BmN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_owaOUGzL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IdVf8Hr7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_x7ZtoMpl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_z9I6b4PB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HqEXF0l9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_olrsBJ8C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wPNZJxxw_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_v95Gy9DU;
  SignalPhasor sPhasor_Ls2aYHQK;
  SignalLine sLine_RsR9btNi;
  SignalRPole sRPole_WvLNFL99;
  SignalRPole sRPole_lLgFnuVU;
  SignalTabhead sTabhead_6xCczABB;
  SignalTabread sTabread_Wl1SMhCh;
  SignalTabread sTabread_ABuRdw3C;
  SignalLine sLine_mCikxCKZ;
  SignalTabhead sTabhead_5kidU1NS;
  SignalTabread sTabread_Aph5mmhV;
  SignalTabread sTabread_kpMe1xQ4;
  SignalLine sLine_AcjqgN0E;
  SignalTabwrite sTabwrite_oOkSPzYC;
  SignalTabwrite sTabwrite_cmQQ1WiW;
  ControlVar cVar_bmh3msR8;
  ControlVar cVar_6ScDnEN2;
  ControlVar cVar_iU2sp8qX;
  ControlVar cVar_KkdYGMiT;
  ControlBinop cBinop_dU4s51nF;
  ControlBinop cBinop_3taU04Is;
  ControlVar cVar_UmUSyyQ1;
  ControlBinop cBinop_yRsAwExd;
  ControlBinop cBinop_7CG3hPQm;
  SignalVarf sVarf_sPCLE0Ew;
  SignalVarf sVarf_d9K8x5EM;
  SignalVarf sVarf_GATTzl0e;
  ControlVar cVar_OB6vEMbV;
  ControlBinop cBinop_NuwUz9y3;
  ControlBinop cBinop_i8eGDwm8;
  SignalVarf sVarf_BpcX2vdC;
  SignalVarf sVarf_KkeUbrj2;
  SignalVarf sVarf_6WlGvP95;
  ControlBinop cBinop_Kuf33ZKD;
  ControlBinop cBinop_jHFMHdIh;
  ControlBinop cBinop_yGlZLUwT;
  ControlBinop cBinop_8wAhAN2V;
  ControlBinop cBinop_CUzfUuSE;
  ControlBinop cBinop_J3IPFYZZ;
  ControlBinop cBinop_0azvQ0Sp;
  ControlBinop cBinop_uSy1dwkt;
  ControlBinop cBinop_sTAF5m5z;
  ControlBinop cBinop_QblfbsDk;
  ControlDelay cDelay_dQmWTum8;
  ControlDelay cDelay_Pg5eDwCG;
  ControlBinop cBinop_T4bDQoQp;
  HvTable hTable_XuXSLJKI;
  ControlBinop cBinop_5VeDqcp1;
  ControlDelay cDelay_JQj6kaOt;
  ControlDelay cDelay_hdGzO2kT;
  ControlBinop cBinop_an7I2YlE;
  HvTable hTable_dh73MCvo;
  ControlBinop cBinop_cbmwTqdB;
  ControlVar cVar_9PnoCOyu;
  ControlBinop cBinop_nymZzzbD;
  ControlBinop cBinop_rEASrGWd;
  SignalVarf sVarf_RD5legC0;
  ControlBinop cBinop_7F5KOczm;
  ControlBinop cBinop_xxgHGyrz;
  ControlBinop cBinop_WYjfM40z;
  SignalVarf sVarf_3Nxvy3I8;
  ControlVar cVar_H9f5b0kF;
  ControlBinop cBinop_DFfC0Xla;
  ControlBinop cBinop_Y6SvP16p;
  SignalVarf sVarf_qQEsPzzO;
  ControlBinop cBinop_uIWBCiAh;
  ControlBinop cBinop_04PE3qBO;
  ControlBinop cBinop_4uO9w57y;
  SignalVarf sVarf_HG38Sw2Q;
  ControlBinop cBinop_jZxprkHg;
  ControlBinop cBinop_SNCqhAuZ;
  ControlBinop cBinop_SueNE6xJ;
  ControlBinop cBinop_YPi80CDP;
  ControlBinop cBinop_naWFw9J8;
  ControlBinop cBinop_hxSqN5eQ;
  ControlBinop cBinop_swIOgw3c;
  ControlSlice cSlice_MrOPaoeR;
  ControlVar cVar_qXnHcB16;
  ControlSlice cSlice_cx1ii3Os;
  ControlVar cVar_3803VhGc;
  ControlSlice cSlice_2iFjGfeb;
  ControlVar cVar_6LWwCAR3;
  ControlSlice cSlice_ENgNmkxM;
  ControlVar cVar_yrzQLza0;
  ControlBinop cBinop_eHOErdVV;
  ControlBinop cBinop_V0pjFmHY;
  ControlBinop cBinop_7nmOYnnK;
};

#endif // _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
